@@ -1,6 +1,7 @@
 var globals_defs =
 [
-    [ "a", "globals_defs.html", null ],
+    [ "_", "globals_defs.html", null ],
+    [ "a", "globals_defs_a.html", null ],
     [ "b", "globals_defs_b.html", null ],
     [ "c", "globals_defs_c.html", null ],
     [ "d", "globals_defs_d.html", null ],
