@@ -1,5 +1,18 @@
 var NAVTREEINDEX7 =
 {
+"structpw__device__info.html#accce9f7bcbbb1e5142298f18ce03d799":[10,0,33,2],
+"structpw__device__info.html#ad8eb88e166e5527d4d5f418e591274c0":[10,0,33,3],
+"structpw__device__methods.html":[10,0,34],
+"structpw__device__methods.html#a50406b74540f4535df9b01ae15cfcfe0":[10,0,34,3],
+"structpw__device__methods.html#a8210738d5878d65481bc918ff935aa80":[10,0,34,1],
+"structpw__device__methods.html#a8251c871164651bcff0d7375ebd75440":[10,0,34,2],
+"structpw__device__methods.html#a9141d0e02e0c16303f59f79d4c1569d8":[10,0,34,4],
+"structpw__device__methods.html#abe74e1fc28413c676391beffec0ba250":[10,0,34,0],
+"structpw__export__type.html":[10,0,35],
+"structpw__export__type.html#a2a49749c0d81fc22b2d70845a5c04e3b":[10,0,35,2],
+"structpw__export__type.html#a753c33021857c67d7bd9df56ebd13116":[10,0,35,1],
+"structpw__export__type.html#a9cdf9b8ac9d405896d45acce48fb1c72":[10,0,35,0],
+"structpw__factory__events.html":[10,0,36],
 "structpw__factory__events.html#a2408a490257998e8aec63c452b450024":[10,0,36,0],
 "structpw__factory__events.html#a92c9ad52c5b502a07bb45e29504dad2f":[10,0,36,1],
 "structpw__factory__info.html":[10,0,37],
@@ -236,18 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__properties.html#a8003e978689f764bb7bd2a3ab2d46a87":[10,0,86,15],
 "structpw__properties.html#aa31ae496c298076852173e46a8c58da5":[10,0,86,6],
 "structpw__properties.html#ab8d32d79721d753deb979f2698fff034":[10,0,86,9],
-"structpw__properties.html#aea9bdd771760e44ca7d77b5113297610":[10,0,86,7],
-"structpw__properties.html#aef040055887634f636bb26594091c31c":[10,0,86,5],
-"structpw__protocol__client.html":[10,0,88],
-"structpw__protocol__client.html#a020b1da93f4f58c485ff64da4a5ac655":[10,0,88,0],
-"structpw__protocol__client.html#a03ad2913f7876e0db722b6d1e318e35f":[10,0,88,2],
-"structpw__protocol__client.html#a0f94b0fb5b1f83cbb56529b5c43c4a8f":[10,0,88,1],
-"structpw__protocol__client.html#a2f6233dcd7a026275a93680ae68ee263":[10,0,88,6],
-"structpw__protocol__client.html#a4b60903a56e79e980b11ea2d14fac80c":[10,0,88,4],
-"structpw__protocol__client.html#a4f79f140a57922a8c4b7d52f9f433918":[10,0,88,7],
-"structpw__protocol__client.html#a9ce571a5bc950b3309d0dbd2a55e501f":[10,0,88,3],
-"structpw__protocol__client.html#addd42578b59ddffc32a42a52754654be":[10,0,88,5],
-"structpw__protocol__client.html#ae94059a4fa05da14961edb56be183f2a":[10,0,88,8],
-"structpw__protocol__events.html":[10,0,89],
-"structpw__protocol__events.html#ab341415c5d72294c801c580ac9653426":[10,0,89,0]
+"structpw__properties.html#aea9bdd771760e44ca7d77b5113297610":[10,0,86,7]
 };
