@@ -1,5 +1,18 @@
 var NAVTREEINDEX8 =
 {
+"structpw__properties.html#aef040055887634f636bb26594091c31c":[10,0,86,5],
+"structpw__protocol__client.html":[10,0,88],
+"structpw__protocol__client.html#a020b1da93f4f58c485ff64da4a5ac655":[10,0,88,0],
+"structpw__protocol__client.html#a03ad2913f7876e0db722b6d1e318e35f":[10,0,88,2],
+"structpw__protocol__client.html#a0f94b0fb5b1f83cbb56529b5c43c4a8f":[10,0,88,1],
+"structpw__protocol__client.html#a2f6233dcd7a026275a93680ae68ee263":[10,0,88,6],
+"structpw__protocol__client.html#a4b60903a56e79e980b11ea2d14fac80c":[10,0,88,4],
+"structpw__protocol__client.html#a4f79f140a57922a8c4b7d52f9f433918":[10,0,88,7],
+"structpw__protocol__client.html#a9ce571a5bc950b3309d0dbd2a55e501f":[10,0,88,3],
+"structpw__protocol__client.html#addd42578b59ddffc32a42a52754654be":[10,0,88,5],
+"structpw__protocol__client.html#ae94059a4fa05da14961edb56be183f2a":[10,0,88,8],
+"structpw__protocol__events.html":[10,0,89],
+"structpw__protocol__events.html#ab341415c5d72294c801c580ac9653426":[10,0,89,0],
 "structpw__protocol__events.html#af7bb9abb40f974acecda6bb2c6ad5cad":[10,0,89,1],
 "structpw__protocol__implementaton.html":[10,0,90],
 "structpw__protocol__implementaton.html#a5dbc29661309ba54e93539eae72ba595":[10,0,90,0],
@@ -79,16 +92,17 @@ var NAVTREEINDEX8 =
 "structregistry.html":[10,0,108],
 "structregistry.html#a395958760b70738836a0aaad7d641fbf":[10,0,108,0],
 "structresource__data.html":[10,0,109],
-"structresource__data.html#a10818e72fb4b7e69e713b6e4f1cfe4b5":[10,0,109,7],
+"structresource__data.html#a10818e72fb4b7e69e713b6e4f1cfe4b5":[10,0,109,8],
 "structresource__data.html#a17b2ae2575ff92e24e1295b5cf8dd040":[10,0,109,0],
 "structresource__data.html#a1ba0b9c4f96dec005b0579a9fe4097ed":[10,0,109,1],
 "structresource__data.html#a2c356777100b44207f8b9c2bfa0dc7ef":[10,0,109,2],
-"structresource__data.html#a50161316a8dbc6f017625d7ae7cc1830":[10,0,109,9],
+"structresource__data.html#a4359b8e5ca98a4da69d920c155f759f5":[10,0,109,6],
+"structresource__data.html#a50161316a8dbc6f017625d7ae7cc1830":[10,0,109,10],
 "structresource__data.html#a53c387cc88d8b3aabdeb5f21a7524df0":[10,0,109,4],
-"structresource__data.html#a6cc97539aba095db1fa33569183e4e04":[10,0,109,6],
+"structresource__data.html#a6cc97539aba095db1fa33569183e4e04":[10,0,109,7],
 "structresource__data.html#a70a2dfa3889e379272d25fece3591f6f":[10,0,109,5],
 "structresource__data.html#a7bdfe353b29ac14ebe5b645618c18d2a":[10,0,109,3],
-"structresource__data.html#ac695a0f85d24f0a28cb971cc4a7ca191":[10,0,109,8],
+"structresource__data.html#ac695a0f85d24f0a28cb971cc4a7ca191":[10,0,109,9],
 "structresult__device__params__data.html":[10,0,110],
 "structresult__device__params__data.html#a485ab9bc6d5dbaf4285876053b8f1902":[10,0,110,0],
 "structresult__device__params__data.html#af601dbb7d11417aae89f45c1749ced54":[10,0,110,1],
@@ -101,40 +115,42 @@ var NAVTREEINDEX8 =
 "structresult__port__params__data.html#a49e188b8ba0176055372ff17a3cac730":[10,0,112,2],
 "structresult__port__params__data.html#abc773dd47328b0981e7a6f03be65a1f7":[10,0,112,1],
 "structstream.html":[10,0,113],
-"structstream.html#a00d21063b64b6339d257433d02a0d5bc":[10,0,113,31],
-"structstream.html#a0b67dcf51974d8cf6b73151658d42be3":[10,0,113,11],
-"structstream.html#a0d379de7ce670bca527a67104d3a2ffc":[10,0,113,25],
-"structstream.html#a1000143671503ec1a7a1a0ddad5a0b5b":[10,0,113,33],
-"structstream.html#a205abb8810d099ecd79ff9afd7931428":[10,0,113,30],
-"structstream.html#a234356f9ddb74bc10ccdf7f8abf439e8":[10,0,113,9],
-"structstream.html#a23cb7ea3db9d2b68df60709b71ee522c":[10,0,113,27],
-"structstream.html#a2a4b596a8fd6684e563544921631bfde":[10,0,113,2],
-"structstream.html#a2afd916c12d7d91bddd23b30f709c582":[10,0,113,3],
-"structstream.html#a33ef55c30dba3f533ce558a3a8918d6c":[10,0,113,15],
-"structstream.html#a369dbaa5cdda9aad66fc4ee6af6cc911":[10,0,113,7],
-"structstream.html#a386c312c7ee7ec6ad015165614514b6f":[10,0,113,8],
-"structstream.html#a3893af848bb4d21b0868f98fa7b79718":[10,0,113,28],
-"structstream.html#a40880651364a231150d4d616b1bcea45":[10,0,113,26],
-"structstream.html#a41be007c6de999aff0def3e6bb0e1652":[10,0,113,13],
-"structstream.html#a4277cb8aee76d493dd3fe7c5292b9d19":[10,0,113,12],
-"structstream.html#a53964295d5a2b27dd8a2eead24f3dfd6":[10,0,113,6],
-"structstream.html#a5748defaf6f10586b00f8cd66aea87f2":[10,0,113,21],
-"structstream.html#a5dad5c71aca03c94d3bf873b9f575c58":[10,0,113,1],
-"structstream.html#a5e861c5f495c43750eda66e177a1b9c3":[10,0,113,10],
-"structstream.html#a62e63fe261a3eabe917744e31fb542bd":[10,0,113,17],
-"structstream.html#a669c175165bd2b3898f2a02d37ac2819":[10,0,113,5],
-"structstream.html#a8d11046e448d4132d6f54070efc1a34f":[10,0,113,19],
-"structstream.html#a8d83d64c0a423d59c8e42fd6bf22d286":[10,0,113,29],
-"structstream.html#a92c53f2e6b9f65b88dfef92d4d6db996":[10,0,113,20],
-"structstream.html#a9c0baf86f50f5b3961b0f12803108c0f":[10,0,113,22],
-"structstream.html#a9de6d02605037e6dfe335552c2e398a3":[10,0,113,4],
-"structstream.html#abc4bd0629266976bb016a722584ed09c":[10,0,113,32],
-"structstream.html#abdd59e087d05441c1ce0cdad1b2e2db6":[10,0,113,24],
-"structstream.html#ac5c81fe4d3d48b283d1379d45b92cccd":[10,0,113,18],
-"structstream.html#ac744f31dcf0b62846bd67d2a525834f7":[10,0,113,16],
+"structstream.html#a00d21063b64b6339d257433d02a0d5bc":[10,0,113,34],
+"structstream.html#a0b67dcf51974d8cf6b73151658d42be3":[10,0,113,13],
+"structstream.html#a0d379de7ce670bca527a67104d3a2ffc":[10,0,113,27],
+"structstream.html#a205abb8810d099ecd79ff9afd7931428":[10,0,113,33],
+"structstream.html#a234356f9ddb74bc10ccdf7f8abf439e8":[10,0,113,11],
+"structstream.html#a23cb7ea3db9d2b68df60709b71ee522c":[10,0,113,29],
+"structstream.html#a2a4b596a8fd6684e563544921631bfde":[10,0,113,3],
+"structstream.html#a2afd916c12d7d91bddd23b30f709c582":[10,0,113,4],
+"structstream.html#a33ef55c30dba3f533ce558a3a8918d6c":[10,0,113,17],
+"structstream.html#a369dbaa5cdda9aad66fc4ee6af6cc911":[10,0,113,9],
+"structstream.html#a386c312c7ee7ec6ad015165614514b6f":[10,0,113,10],
+"structstream.html#a3893af848bb4d21b0868f98fa7b79718":[10,0,113,31],
+"structstream.html#a40880651364a231150d4d616b1bcea45":[10,0,113,28],
+"structstream.html#a41be007c6de999aff0def3e6bb0e1652":[10,0,113,15],
+"structstream.html#a4277cb8aee76d493dd3fe7c5292b9d19":[10,0,113,14],
+"structstream.html#a44a13a68b47b97b3bef41f3e801d09e6":[10,0,113,1],
+"structstream.html#a53964295d5a2b27dd8a2eead24f3dfd6":[10,0,113,8],
+"structstream.html#a5748defaf6f10586b00f8cd66aea87f2":[10,0,113,23],
+"structstream.html#a5dad5c71aca03c94d3bf873b9f575c58":[10,0,113,2],
+"structstream.html#a5e13d0a14c7715023a92ea6e5d1b603e":[10,0,113,5],
+"structstream.html#a5e861c5f495c43750eda66e177a1b9c3":[10,0,113,12],
+"structstream.html#a62e63fe261a3eabe917744e31fb542bd":[10,0,113,19],
+"structstream.html#a669c175165bd2b3898f2a02d37ac2819":[10,0,113,7],
+"structstream.html#a6fbe7e913ff0273df637ac36bdd3c1ff":[10,0,113,30],
+"structstream.html#a8d11046e448d4132d6f54070efc1a34f":[10,0,113,21],
+"structstream.html#a92c53f2e6b9f65b88dfef92d4d6db996":[10,0,113,22],
+"structstream.html#a9c0baf86f50f5b3961b0f12803108c0f":[10,0,113,24],
+"structstream.html#a9de6d02605037e6dfe335552c2e398a3":[10,0,113,6],
+"structstream.html#abc4bd0629266976bb016a722584ed09c":[10,0,113,35],
+"structstream.html#abdd59e087d05441c1ce0cdad1b2e2db6":[10,0,113,26],
+"structstream.html#ac298f5408638d169987a26ccc7bc3fbb":[10,0,113,32],
+"structstream.html#ac5c81fe4d3d48b283d1379d45b92cccd":[10,0,113,20],
+"structstream.html#ac744f31dcf0b62846bd67d2a525834f7":[10,0,113,18],
 "structstream.html#acfe5ed66bf6536300e724a6649ba5a62":[10,0,113,0],
-"structstream.html#ae65e184bbaaf7dd6d6ac820a773c738a":[10,0,113,23],
-"structstream.html#af472f42f40a7c7bb801fe844e228aed6":[10,0,113,14],
+"structstream.html#ae65e184bbaaf7dd6d6ac820a773c738a":[10,0,113,25],
+"structstream.html#af472f42f40a7c7bb801fe844e228aed6":[10,0,113,16],
 "structsupport.html":[10,0,114],
 "structsupport.html#a0474423b9a6c7f4671e29b6c1f8e4ff3":[10,0,114,1],
 "structsupport.html#a54886fd6eea1bc3f72e01d23ec2b2c12":[10,0,114,4],
